#!/usr/bin/env python
# -*- coding: utf-8 -*-

# TODO expand this module to create a full .bib bibliography file with
# proper links inside the document.  Much of the code to do this for
# doi and pmid links is already present in the Perl file.  (Due to the
# limited and largely unstructured information provided by isbn lookup
# services, I don't think it is plausible to do citations for these.)

from __future__ import unicode_literals

# UTF8?
import codecs, sys
sys.stdout = codecs.getwriter('utf-8')(sys.stdout)

# More UTF8?
import sys
reload(sys)
sys.setdefaultencoding('utf-8')

from subprocess import Popen, PIPE # For calling Perl

"""Pandoc filter for allowing easy citations to scientific papers.
Citations can be created using the normal link syntax, but instead of
making a normal link, the link text should be "doi:xxx", "pmid:xxx",
or "isbn:xxx", where "xxx" is replaced by the appropriate doi, pmid,
or isbn identifier.  This will erase any linked text as well, and
replace it with a crude parenthetical citation.  It also caches the
results to avoid unnecessary web traffic.

Note that this filter requires Perl!  Also, I have only tested it on
GNU/Linux.  I would imagine it works fine on all *nix systems and
fails miserably on Windows systems.

"""

from pandocfilters import toJSONFilter, Link, Str
import sys # for stderr debugging
import re # To match the doi/pmid/isbn patterns

# Take a JSON object as input.  The following is the structure of the
# link object:
# 
# {t: "Link" or "Image"
#  c: [ [ Inline elements ]
#       [ "Link url", "Link title (optional)" ]
#     ]
# 
# For each link that begins with "pmid:", "doi:", or "isbn:", this
# will look up the citations using a web service.  It will replace the
# link title with the first author's last name and the date in
# parentheses, and link to the article.  If I have time, I may expand
# it in the future to tie in with pandoc's citations.
def citationsproc(key, value, format, meta):
    if key == 'Link':
        [linktext, urlproperties] = value
        m = re.match(r'(doi|pmid|isbn):(.+)', urlproperties[0])
        if m == None: return
        else: # i.e. m.group(1) in ['doi', 'pmid', 'isbn']:
            # I am lazy so here is my legacy Perl code.  Enjoy.
            citation = Popen(["perl", "fetchcitation.pl", urlproperties[0]], stdout=PIPE).communicate()[0]
            citation = citation.split("\t")
            urlproperties[0] = citation[1]
            linktext = [Str(citation[0])]
            return Link(linktext, urlproperties)

if __name__ == "__main__":
    toJSONFilter(citationsproc)

