#!/usr/bin/env python
# -*- coding: utf-8 -*-

from __future__ import unicode_literals

# UTF8?
import codecs, sys
sys.stdout = codecs.getwriter('utf-8')(sys.stdout)

# More UTF8?
import sys
reload(sys)
sys.setdefaultencoding('utf-8')

import os # For checking if directories exist and making them
from datadirfilter import getMetaString
import json # For manually doing the "toJSONfilter" function

from pandocfilters import walk, CodeBlock
import re

# Cross-reference from file extension to the pandoc language
# identifier. The name of each potential file name is the key, and the
# value is the identifier.
langs = {'hs': 'haskell',
         'css': 'css',
         'htm': 'html',
         'html': 'html',
         'js': 'javascript',
         'pl': 'perl',
         'php': 'php',
         'php5': 'php',
         'php4': 'php',
         'py': 'python',
         'rb': 'ruby',
         'xml': 'xml',
         'c': 'c',
         'cpp': 'cpp',
         'h': 'c',
         'hpp': 'cpp',
         'm': 'octave',
         'gnuplot': 'gnuplot',
         'sh': 'bash',
         'erl': 'erlang',
         'el': 'lisp',
         'r': 'R'}

# When code is extracted, this is the directory where the files are
# saved.  Should contain a trailing slash.
defaultdir = './'
defaultdatadirdir = 'generated-scripts/'

# The following is the syntax for the CodeBlock format:
#
# CodeBlock = {
#   [ [ ID,
#       [ attributes ]
#       [[attributekey value]...] ]
#     code ]
# 

# Store file content here as we go through the file.  Then, at the
# end, write out the content to the file.
filecontent = {}
linenum = {}
def codeproc(key, value, format, meta):
    if key == 'CodeBlock':
        [meta, contents] = value
        [codeid, attr, kv] = meta
        # If it has an attribute that is in the structure of a file
        # name, assume it is indeed a file name.
        for a in attr:
            m = re.match(r'([A-Za-z0-9\-]+)\.([A-Za-z]+)', a)
            if m != None:
                if m.group(2) in langs.keys():
                    attr.append(langs[m.group(2)])
                    # Get lines numbered correctly
                    attr.append("numberLines")
                    if m.group(0) in linenum:
                        kv.append(['startFrom', unicode(1+linenum[m.group(0)])])
                        linenum[m.group(0)] += len(contents.split("\n"))
                    else:
                        kv.append(['startFrom', '1'])
                        linenum[m.group(0)] = len(contents.split("\n"))
                    

                    # Save the code to be output to its own file.
                    if m.group(0) in filecontent:
                        filecontent[m.group(0)] += contents+"\n"
                    else:
                        filecontent[m.group(0)] = contents+"\n"
                    # Replace it with one that will get highlighted
                    meta = [codeid, attr, kv]
                    value = [meta, contents]
                    return CodeBlock(meta, contents)

if __name__ == "__main__":
    # TODO make directory if it doesn't exist
    doc = json.loads(sys.stdin.read())
    if len(sys.argv) > 1:
        format = sys.argv[1]
    else:
        format = ""
    meta = doc[0]['unMeta']
    altered = walk(doc, codeproc, format, doc[0]['unMeta'])
    json.dump(altered, sys.stdout)
    # Integration with the datadirfilter.py filter
    filename = getMetaString('filename', meta)
    if filename != None:
        if os.path.isdir(filename+".d"):
            defaultdir = filename + ".d/" + defaultdatadirdir
    # Don't try to write to an empty directory
    if not os.path.isdir(defaultdir) and not os.path.exists(defaultdir):
        os.mkdir(defaultdir)
    for fn, c in filecontent.iteritems():
        f = codecs.open(defaultdir+fn, 'w')
        f.write(c)
        f.close()


