#!/usr/bin/env python
# -*- coding: utf-8 -*-

from __future__ import unicode_literals

# UTF8?
import codecs, sys
sys.stdout = codecs.getwriter('utf-8')(sys.stdout)

# More UTF8?
import sys
reload(sys)
sys.setdefaultencoding('utf-8')

"""Pandoc filter for creating a default directory, $filename.d, for
all files referenced. This is a part of notes3.  For a similar
implementation (notes2), see:
http://bazaar.launchpad.net/~trombonechamp/+junk/notes/view/head:/latexify-notes.pl.n

"""

from pandocfilters import toJSONFilter, Link, Image
import sys # for stderr debugging
import os # For checking if files exist

# Returns the meta string with the given key.  This is useful for
# getting parameters passed via the command line.  The `meta` variable
# should contain doc[0]['unMeta'].  The value returned will be a
# string on success.  Returns None on failure.
def getMetaString(key, meta):
    if key in meta:
        if meta[key]['t'] == 'MetaString':
            return meta[key]['c']
    return None

def datadir_path(meta):
    filename = getMetaString('filename', meta)
    return filename + ".d/" if (filename != None) else None

# Take a JSON object as input.  The following is the structure of the
# link and image objects:
# 
# {t: "Link" or "Image"
#  c: [ [ Inline elements ]
#       [ "Link url", "Link title (optional)" ]
#     ] }
# 
# For each url listed, if it exists as a file inside the file's
# subdirectory (filename.d), it will link to the file within the
# subdirectory instead.  Anything in the subdirectory is given
# priority.
def urlproc(key, value, format, meta):
    if key in ['Link', 'Image']:
        [linktext, urlproperties, attr] = value
        datadir = datadir_path(meta) # We could speed this up by only calling this function once in the __name__ == "__main__" section, but then we wouldn't be able to use toJSONFilter.
        if datadir != None:
            if os.path.exists(datadir + urlproperties[0]):
                urlproperties[0] = datadir + urlproperties[0]
                if key == 'Link':
                    return Link(linktext, urlproperties, attr)
                elif key == 'Image':
                    return Image(linktext, urlproperties, attr)

if __name__ == "__main__":
    toJSONFilter(urlproc)

