#!/usr/bin/env python
# -*- coding: utf-8 -*-

from __future__ import unicode_literals

# UTF8?
import codecs, sys
sys.stdout = codecs.getwriter('utf-8')(sys.stdout)

# More UTF8?
import sys
reload(sys)
sys.setdefaultencoding('utf-8')

import json

# The pandocfilters module doesn't define constructors for meta
from pandocfilters import elt, Plain, Str, Space
MetaInlines = elt('MetaInlines', 1) # Takes a list of inlines as its argument
MetaBlocks = elt('MetaBlocks', 1) # Takes a list of blocks as its argument
MetaString = elt('MetaString', 1) # Takes the string as its argument

# The JSON structure of the metadata is:
# unMeta = {
#          'key': {
#                 t: 'MetaInlines'
#                 c: [ {
#                      t: 'Str' (or 'Space', 'Plain', etc.)
#                      c: ''
#                      } 
#                      ...
#                    ] 
#                  }
#           ... 
#           }
if __name__ == "__main__":
    # TODO make directory if it doesn't exist
    doc = json.loads(sys.stdin.read())
    if len(sys.argv) > 1:
        format = sys.argv[1]
    else:
        format = ""
    meta = doc[0]['unMeta']
    # Make "By:" equivalent to "Author:"
    if 'by' in meta and 'author' not in meta:
        meta['author'] = meta.pop('by')

    # Check if the last paragraph starts with the phrase "Closed: ".
    # If so, remove it from the document tree and treat it as
    # metadata.
    if doc[1][len(doc[1])-1]['t'] == 'Para' and \
       doc[1][len(doc[1])-1]['c'][0]['t'] == 'Str' and \
       doc[1][len(doc[1])-1]['c'][0]['c'] == 'Closed:' and \
       doc[1][len(doc[1])-1]['c'][1]['t'] == 'Space' and \
       len(doc[1][len(doc[1])-1]['c']) > 2:
        if 'closed' not in meta:
            closed = doc[1][len(doc[1])-1]['c']
            closed.pop(0) # Remove "Closed: "
            closed.pop(0) # Remove Space
            doc[1].pop(len(doc[1])-1)
            meta['closed'] = MetaBlocks([Plain(closed)])
        else:
            print >> sys.stderr, "You can only open a document once!"

    # If this has the "Due" tag (for a due date), we don't care about
    # any other dates listed.  We will list the date as the due date.
    if 'due' in meta:
        meta['date'] = meta.pop('opened')        

    # Add the word "Opened" before the date
    if 'opened' in meta and 'date' not in meta and 'closed' not in meta:
        meta['opened']['c'][0]['c'].reverse()
        meta['opened']['c'][0]['c'].extend([Space(), Str("Opened:")]) # Backwards for reverse
        meta['opened']['c'][0]['c'].reverse()
        meta['date'] = meta.pop('opened')

    if 'opened' in meta and 'date' not in meta and 'closed' in meta:
        meta['closed']['c'][0]['c'].reverse()
        meta['closed']['c'][0]['c'].extend([Space(), Str("\u2013"), Space()]) # Backwards for reverse
        meta['closed']['c'][0]['c'].reverse()
        meta['opened']['c'][0]['c'].extend(meta['closed']['c'][0]['c'])
        meta['date'] = meta.pop('opened')
        meta.pop('closed')

    # TODO Parse through metadata and append to the document.
    # print >> sys.stderr, doc # Debug
    #exit() # Debug
    # Save and exit.
    doc[0]['unMeta'] = meta
    json.dump(doc, sys.stdout)
