#!/usr/bin/env python
# -*- coding: utf-8 -*-

from __future__ import unicode_literals

# UTF8?
import codecs, sys
sys.stdout = codecs.getwriter('utf-8')(sys.stdout)

# More UTF8?
import sys
reload(sys)
sys.setdefaultencoding('utf-8')

"""Pandoc filter for important text.  This draws attention to
paragraphs prefixed by "->" by typesetting them differently.  This
filter also emphasizes paragraphs that begin with "UPDATE (#): "
where "#" is a date (numbers, slashes, and hyphens)."""

from pandocfilters import toJSONFilter, Math, Para, BlockQuote, DefinitionList, Emph, Str, Space
import re
import sys # for stderr debugging
from mathgrammar import parse_math

# Take a JSON object as input.  Though the structure of this JSON
# object is not very well-documented, the following is the structure
# of the paragraph object:
# 
# {t: "Para"
#  c: [ { t: "Str", c: "..." },
#       { t: "Space", c: [] }, ...
#       ]
#  }
# 
# This function processes the document and replaces paragraphs
# starting with "-> " with a more emphasized version of the paragraph.
def importantproc(key, value, format, meta):
    if key == 'Para':
        #print >> sys.stderr, value
        # Check if it is -> followed by a space
        if len(value) < 2: return
        if value[0]['t'] == 'Str' and \
           value[0]['c'] == '->' and \
           value[1]['t'] == 'Space':
            # Remove the -> and the space
            value.reverse()
            value.pop()
            value.pop()
            value.reverse()
            return BlockQuote([DefinitionList([[[Math({"t": "InlineMath", "c": []}, "\\Longrightarrow")], [[Para([Emph(value)])]]]])])
        # Check for UPDATE (xxx): syntax
        if len(value) < 4: return
        if value[0]['t'] == 'Str' and \
           value[0]['c'] == 'UPDATE' and \
           value[1]['t'] == 'Space' and \
           value[2]['t'] == 'Str' and \
           value[3]['t'] == 'Space':
            m = re.match(r'\([0-9/-]+\):', value[2]['c'])
            if m != None:
                # Remove the "UPDATE (xxx): "
                value.reverse()
                value.pop()
                value.pop()
                value.pop()
                value.reverse()
                return BlockQuote([DefinitionList([[[Str("Update"), Space(), Str(m.group(0))], [[Para(value)]]]])])


if __name__ == "__main__":
    toJSONFilter(importantproc)

