#!/usr/bin/env python
# -*- coding: utf-8 -*-

from __future__ import unicode_literals

# UTF8?
import codecs, sys
sys.stdout = codecs.getwriter('utf-8')(sys.stdout)

# More UTF8?
import sys
reload(sys)
sys.setdefaultencoding('utf-8')

"""Pandoc filter for simplified LaTeX math.  This is an implementation
of the LaTeX math extensions I developed in the perl script notes2.
For documentation of the format, see the documentation in:
http://bazaar.launchpad.net/~trombonechamp/+junk/notes/view/head:/latexify-notes.pl.n
"""

from pandocfilters import toJSONFilter, Math
import re
import sys # for stderr debugging
from mathgrammar import parse_math, MathGrammarError

# I really need to rewrite this to use lex/yacc...

# A list of functions that may appear inline and are to be displayed
# in roman face.  They must also be defined in the LaTeX header, if
# not included in LaTeX itself (such as \sin).
rmfuns = ["sin", "cos", "tan", "arcsin", "arccos", "arctan", "asin",
           "acos", "atan", "sec", "csc", "cot", "ln", "log", "max",
           "min", "sup", "inf", "ker", "coker", "rng", "corng", "var",
           "rank", "rk", "exp", "erf", "det", "tr", "lim", "Cov",
           "Var", "Bias", "Median"]

# Take a JSON object as input.  Though the structure of this JSON
# object is not very well-documented, the following is the structure
# of the math object:
# 
# {t: "Math"
#  c: [ { t: "InlineMath", c: [] },
#       "x + y = z"]}
# 
# "InlineMath" can also be "DisplayMath".  This function processes the
# body of the math and returns another JSON object with the same
# structure.
def mathproc(key, value, format, meta):
    if key == 'Math':
        [mathtype, contents] = value
        # If we are dealing with inline math, our job is easy
        if mathtype['t'] == 'InlineMath':
            return Math(mathtype, parse_math(contents.strip()))
        # If we are dealing with display math, we have to run checks
        # to make sure that it does not need to be aligned.  We do
        # this by counting the number of ampersands on each line.  If
        # they are equal, we are all set. If not, there was a syntax
        # error.
        else:
            contents = contents.strip()
            lines = contents.split("\n")
            def countampersands(s): # Made to not be a method for map.
                return s.count('&')
            lineamps = map(countampersands, lines) # List of counts
            if len(set(lineamps)) == 1 and len(lineamps) > 1: # All elements in the list are the same
                fullmath = "\\begin{aligned}" + parse_math(contents) + "\\end{aligned}"
            elif len(set(lineamps)) != 1:
                raise MathGrammarError("Bad ampersand count in equation:\n\n"+contents)
            else:
                fullmath = parse_math(contents)
            return Math(mathtype, fullmath)
        return []

if __name__ == "__main__":
    try:
        toJSONFilter(mathproc)
    except MathGrammarError as e:
        print >> sys.stderr, "="*30
        print >> sys.stderr, "MATH ERROR:"
        print >> sys.stderr, e
        print >> sys.stderr, "="*30
        exit(1)

